pymyo
=====

[![PyPI](https://img.shields.io/pypi/v/pymyo)](https://pypi.org/project/pymyo/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pymyo)](https://pypi.org/project/pymyo/)
[![GitHub](https://img.shields.io/github/license/Crimson-Crow/pymyo)]((https://github.com/Crimson-Crow/pymyo/blob/main/LICENSE.txt))

Description
-----------

`pymyo` is a Python module that allows you to configure or retrieve data from a Thalmic Labs Myo armband through BLE **without** the need to have the Myo SDK installed.

WIP
---
Documentation coming soon!
